/* Generated by generator.py */

#include <Python.h>
#include <stdlib.h>
#include <libvirt/libvirt-lxc.h>
#include "typewrappers.h"
#include "libvirt-lxc.h"

PyObject *
libvirt_lxc_virDomainLxcEnterCGroup(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
    PyObject *py_retval;
    int c_retval;
    virDomainPtr domain;
    PyObject *pyobj_domain;
    unsigned int flags;

    if (!PyArg_ParseTuple(args, (char *)"OI:virDomainLxcEnterCGroup", &pyobj_domain, &flags))
        return NULL;
    domain = (virDomainPtr) PyvirDomain_Get(pyobj_domain);

    LIBVIRT_BEGIN_ALLOW_THREADS;
    c_retval = virDomainLxcEnterCGroup(domain, flags);
    LIBVIRT_END_ALLOW_THREADS;
    py_retval = libvirt_intWrap((int) c_retval);
    return py_retval;
}

